// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef PYSIDE_H
#define PYSIDE_H

#include <sbkpython.h>

#include <pysidemacros.h>

#include "pysideinit.h"
#include "pysideqapp.h"
#include "pysideqobject.h"
#include "pysideutils.h"

#endif // PYSIDE_H
